@@ -484,7 +484,7 @@ void charreport(labelptr curlabel)
       strncat(_STR2, " ", --cleft);
       if (cleft <= 0) break;
    }
-   Wprintf(_STR2);
+   Wprintf("%s", _STR2);
 }
 
 /*----------------------------------------------------------------------*/
@@ -684,7 +684,7 @@ Boolean labeltext(int keypressed, char *clientdata)
 	 /* name is unique, change every pin in the matching symbol/	*/
 	 /* schematic to match the new text.				*/
 
-	 if ((areastruct.schemon == True) && (curlabel->pin != False) && 
+	 if ((areastruct.schemon == True) && (curlabel->pin == LOCAL) && 
 		(topobject->symschem != NULL)) {
 	    if ((findlabelcopy(curlabel, labelbuf) == NULL)
 			&& (findlabelcopy(curlabel, curlabel->string) == NULL)) {
