@@ -47,8 +47,6 @@ extern int *appcolors;
 /*----------------------------------------------*/
 #ifdef LGF
 
-Boolean lgfisloaded = False;
-
 /*----------------------------------------------*/
 /* loadlgf: Load an analog LGF file 		*/
 /*	mode = 1: import into current page;	*/
@@ -75,8 +73,7 @@ void loadlgf(int mode)
 	 sprintf(inname, "%s.lfo", _STR);
 	 ps = fopen(inname, "r");
 	 if (ps == NULL) {
-	    sprintf(_STR, "Can't open LGF file %s", inname);
-            Wprintf(_STR);
+	    Wprintf("Can't open LGF file %s", inname);
 	    return;
          }
       }
@@ -86,17 +83,15 @@ void loadlgf(int mode)
 
    if ((pdchar = strstr(inname, ".l")) != NULL) *pdchar = '\0';
 
-   sprintf(_STR, "Loaded file: %s", inname);
-   Wprintf(_STR);
+   Wprintf("Loaded file: %s", inname);
 
    /* Make sure that LGF object library has been loaded by loading it now. */
 
-   if (!lgfisloaded) {
+   if (check_library(LGF_LIB) < 0) {
       int ilib;
       strcpy(_STR, LGF_LIB);
-      ilib = createlibrary();
+      ilib = createlibrary(FALSE);
       loadlibrary(ilib);
-      lgfisloaded = True;
    }
    
    /* Read header information */
@@ -111,8 +106,7 @@ void loadlgf(int mode)
       return;
    }
    if (*(++pdchar) != '5') {
-      sprintf(_STR, "Don't know how to read version %c.", *pdchar);
-      Wprintf(_STR);
+      Wprintf("Don't know how to read version %c.", *pdchar);
       return;
    }
    if (fgets(temp, 149, ps) == NULL) {
@@ -454,8 +448,7 @@ void loadlgf(int mode)
 
 	       else {
 	          sscanf(lineptr, "%*d %*d %*d %*d %*d %*d %d", &hval);
-	          sprintf(_STR, "No library object %s", tmpstring);
-	          Wprintf(_STR);
+	          Wprintf("No library object %s", tmpstring);
 	       }
 
 	       for (j = 0; j < hval + 1; j++) {
@@ -500,8 +493,7 @@ void loadlgf(int mode)
 	    break;
 
 	default:
-	    sprintf(_STR, "Don't understand statement '%c'", *lineptr);
-	    Wprintf(_STR);
+	    Wprintf("Don't understand statement '%c'", *lineptr);
 	    break;
       }
    }
@@ -510,7 +502,7 @@ void loadlgf(int mode)
 
    for (iolabel = topobject->plist; iolabel < topobject->plist +
 	   topobject->parts; iolabel++)
-      if ((*iolabel)->type == LABEL) {
+      if (IS_LABEL(*iolabel)) {
          if (TOLABEL(iolabel)->rotation == 500) {
 	    genericptr *tmplabel;
 
@@ -564,8 +556,7 @@ void loadmat4(caddr_t nullval)
 	 sprintf(inname, "%s.eps", _STR);
 	 ps = fopen(inname, "r");
 	 if (ps == NULL) {
-	    sprintf(_STR, "Can't open Matlab PostScript file %s", inname);
-            Wprintf(_STR);
+	    Wprintf("Can't open Matlab PostScript file %s", inname);
 	    return;
          }
       }
@@ -575,8 +566,7 @@ void loadmat4(caddr_t nullval)
 
    if ((pdchar = strstr(_STR, ".ps")) != NULL) *pdchar = '\0';
    sprintf(topobject->name, "%s", _STR);
-   sprintf(_STR, "Loaded file: %s", inname);
-   Wprintf(_STR);
+   Wprintf("Loaded file: %s", inname);
    renamepage(areastruct.page);
    printname(topobject);
 
