@@ -164,8 +164,10 @@ void transform_graphic(graphicptr gp)
 
     if (gp->target->data == (char *)NULL) {
        XDestroyImage(gp->target);
+       gp->target = (XImage *)NULL;
        gp->clipmask = (Pixmap)NULL;
        gp->valid = FALSE;
+       return;
     }
 
     if (gp->rotation != 0) {
