@@ -436,7 +436,7 @@ void printeditbindings()
    strcat(_STR2, func_to_string(XCF_Edit_Next));
    free(tstr);
 
-   Wprintf(_STR2);
+   Wprintf("%s", _STR2);
 }
 
 /*--------------------------------------------------------------*/
@@ -472,9 +472,8 @@ void remove_keybinding(const char *keystring, const char *fstring)
    int keywstate = string_to_key(keystring);
 
    if ((function < 0) || (remove_binding(keywstate, function) < 0)) {
-      sprintf(_STR2, "Key binding \'%s\' to \'%s\' does not exist in list.",
+      Wprintf("Key binding \'%s\' to \'%s\' does not exist in list.",
 		keystring, fstring);
-      Wprintf(_STR2);
    }
 }
 
@@ -708,15 +707,10 @@ void default_keybindings()
    }
    else {
       add_binding(BUTTON2, XCF_Text_Return);
-      add_binding(SHIFT | BUTTON1, XCF_Text_Return);
       add_binding(BUTTON2, XCF_Select);
-      add_binding(SHIFT | BUTTON1, XCF_Select);
       add_binding(HOLD | BUTTON2, XCF_SelectBox);
-      add_binding(SHIFT | HOLD | BUTTON1, XCF_Select);
       add_binding(BUTTON2, XCF_Finish_Element);
-      add_binding(SHIFT | BUTTON1, XCF_Finish_Element);
       add_binding(BUTTON2, XCF_Finish_Copy);
-      add_binding(SHIFT | BUTTON1, XCF_Finish_Copy);
       add_binding(BUTTON3, XCF_Cancel_Last);
       add_binding(BUTTON3, XCF_Cancel);
    }
