@@ -892,8 +892,7 @@ void cathide()
       libobj = SELTOOBJINST(newselect);
 
       if (finddepend(libobj, &compobj) == 0) {
-	 sprintf(_STR, "Cannot hide: no dependencies");
-	 Wprintf(_STR);
+	 Wprintf("Cannot hide: no dependencies");
       }
       else { 		/* All's clear to hide. */
 	 libobj->thisobject->hidden = True;
@@ -953,8 +952,7 @@ void catdelete()
       /* or if the object is used on a page.				   */
 
       if (finddepend(libobj, &compobj)) {
-	 sprintf(_STR, "Cannot delete: dependency in \"%s\"", (*compobj)->name);
-	 Wprintf(_STR);
+	 Wprintf("Cannot delete: dependency in \"%s\"", (*compobj)->name);
       }
       else { 		/* All's clear to delete.		     	   */
 
