@@ -1294,12 +1294,6 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
       return;
    }
 
-   /* Cannot form this type of parameter on a top-level page */
-   if (is_page(topobject) != -1) {
-      Wprintf("Cannot form a parameter in a top-level page!");
-      return;
-   }
-
    /* Make sure the parameter doesn't already exist.	   */
 
    for (epp = (*gelem)->passed; epp != NULL; epp = epp->next) {
@@ -1653,13 +1647,6 @@ void makeparam(labelptr thislabel, char *key)
    stringpart *begpart, *endpart;
    char *newkey;
 
-   /* cannot form a parameter on a top-level page */
-
-   if (is_page(topobject) != -1) {
-      Wprintf("Cannot form a parameter in a top-level page!");
-      return;
-   }
-
    /* make sure this does not overlap another parameter */
 
    if (paramcross(topobject, thislabel)) {
