@@ -839,8 +839,11 @@ extern void fontcat_op(int, int, int);
 
 /* from xcircuit.c: */
 
+extern void Wprintf(char *, ...);
+extern void W1printf(char *, ...);
+extern void W2printf(char *, ...);
+
 extern void printeventmode();
-extern void Wprintf(char *);
 extern void popupprompt(xcWidget, char *, char *, void (*function)(),
                         buttonsave *, const char *);
 extern void getproptext(xcWidget, propstruct *, caddr_t);
@@ -851,8 +854,6 @@ extern int xc_getlayoutcolor(int);
 extern int query_named_color(char *);
 extern void outputpopup(xcWidget, caddr_t, caddr_t);
 extern void docommand();
-extern void W1printf(char *);
-extern void W2printf(char *);
 extern void destroypopup(xcWidget, popupstruct *, caddr_t);
 extern int xc_alloccolor(char *);
 extern void dointr(int);
