@@ -1821,8 +1821,7 @@ static PyObject *xc_newtool(PyObject *self, PyObject *args)
       return NULL;
 
    if (XpmReadFileToImage(dpy, (char *)pixfile, &iret, NULL, &attr) < 0) {
-      sprintf(_STR, "Cannot find or open pixmap file \'%s\'", pixfile);
-      Wprintf(_STR);
+      Wprintf("Cannot find or open pixmap file \'%s\'", pixfile);
       XpmCreateImageFromData(dpy, q_xpm, &iret, NULL, &attr);
    }
 
@@ -2009,8 +2008,7 @@ void defaultscript()
    if ((fd = fopen(_STR2, "r")) == NULL) {
       sprintf(_STR2, "%s/%s", BUILTINS_DIR, STARTUP_FILE);
       if ((fd = fopen(_STR2, "r")) == NULL) {
-         sprintf(_STR, "Failed to open startup script \"%s\"\n", STARTUP_FILE);
-         Wprintf(_STR);
+         Wprintf("Failed to open startup script \"%s\"\n", STARTUP_FILE);
 	 return;
       }
    }
@@ -2033,8 +2031,7 @@ void execscript()
       refresh(NULL, NULL, NULL);
    }
    else {
-      sprintf(_STR, "Failed to open script file \"%s\"\n", _STR2);
-      Wprintf(_STR);
+      Wprintf("Failed to open script file \"%s\"\n", _STR2);
    }  
 }
 
