@@ -229,8 +229,7 @@ short execcommand(short pflags, char *cmdptr)
 	 /* Use entire line after 1st argument, so multiple words are allowed */
 	 sptr = argptr + strlen(_STR);
          if (add_keybinding(_STR, sptr) < 0) {
-	    sprintf(_STR, "Function \"%s\" is not known\n", sptr);
-	    Wprintf(_STR);
+	    Wprintf("Function \"%s\" is not known\n", sptr);
 	 }
       }
    }
@@ -415,8 +414,7 @@ void defaultscript()
    if ((fd = fopen(_STR2, "r")) == NULL) {
       sprintf(_STR2, "%s/%s", BUILTINS_DIR, STARTUP_FILE);
       if ((fd = fopen(_STR2, "r")) == NULL) {
-         sprintf(_STR, "Failed to open startup script \"%s\"\n", STARTUP_FILE);
-         Wprintf(_STR);
+         Wprintf("Failed to open startup script \"%s\"\n", STARTUP_FILE);
 	 return;
       }
    }
@@ -434,8 +432,7 @@ void execscript()
    xc_tilde_expand(_STR2, 249);
    if ((fd = fopen(_STR2, "r")) != NULL) readcommand(0, fd);
    else {
-      sprintf(_STR, "Failed to open script file \"%s\"\n", _STR2);
-      Wprintf(_STR);
+      Wprintf("Failed to open script file \"%s\"\n", _STR2);
    }
 }
 
